pub struct ZcosmicToplevelManagerV1 { /* private fields */ }wayland and Linux only.Expand description
control open apps
This protocol allows clients such as a taskbar to request the compositor to preform typical actions on open toplevels. The compositor is in all cases free to ignore the request.
See also the Request enum for this interface.
Implementations
Sourceimpl ZcosmicToplevelManagerV1
impl ZcosmicToplevelManagerV1
Sourcepub fn capabilities(&self, capabilities: Vec<u8>)
pub fn capabilities(&self, capabilities: Vec<u8>)
compositor capabilities
This event advertises the capabilities supported by the compositor. If a capability isn’t supported, clients should hide or disable the UI elements that expose this functionality. For instance, if the compositor doesn’t advertise support for closing toplevels, a button triggering the close request should not be displayed.
The compositor will ignore requests it doesn’t support. For instance, a compositor which doesn’t advertise support for closing toplevels will ignore close requests.
Compositors must send this event once after creation of an zcosmic_toplevel_manager_v1 . When the capabilities change, compositors must send this event again.
The capabilities are sent as an array of 32-bit unsigned integers in native endianness.